<!--温湿计 -->
<template>
    <div class="page-top">
        <div class="page-top-left">
            <DeviceImage :typeId="1421"  :devIns="deviceIns"/>
            <div style="height: 280px; width: 100%; margin-top: 16px;">
                <DeviceInfo :ndata="ndata" />
            </div>
        </div>
        <div class="page-top-right">
            <div class="page-top-right-top">
                <div style="flex: 1; height: 383px; margin-right: 16px;">
                    <HumiditySensor :propertyData="payloadData"/>
                </div>
                <div style="flex: 1; height: 383px;">
                    <TemperatureSensor :propertyData="payloadData" />
                </div>
            </div>
            <div style="flex: 1; height: 439px; margin-top: 16px;">
                <EnvironmentalCurve :cdata="chartValue" />
            </div>
        </div>
    </div>
    <div class="page-bottom">
        <WarningInfo />
    </div>
</template>
<script lang="ts" name="WSJ" setup>
import DeviceInfo from '../components/DeviceInfo.vue';
import DeviceImage from '../components/DeviceImage.vue';
import HumiditySensor from '../components/HumiditySensor.vue';
import TemperatureSensor from '../components/TemperatureSensor.vue';
import EnvironmentalCurve from '../components/EnvironmentalCurve.vue';
import WarningInfo from '../components/WarningInfo.vue';

const props = defineProps({
    ndata: {
        type: Object,
        default: () => {}
    }
});


import { detail } from '@/api/device/instance'
import { DeviceInstance,PropertyData } from "@/views/device/Instance/typings"
const deviceIns = ref<DeviceInstance>();
const metadata = ref<Record<string, any>>({});
const propertyValue = ref<Record<string, any>>({});
const loadDevIns = async ()=>{
    const resp: any = await detail(props.ndata.deviceId)
    if(resp.status === 200){
        deviceIns.value =  resp.result
        metadata.value = JSON.parse(deviceIns.value?.metadata || '{}');
        if(metadata.value.properties){
            metadata.value.properties.forEach((p:any)=>{
                propertyValue.value[p.id] = p
            })
        }
    }   
}


onMounted( async() => {
   await loadDevIns();
    subscribeProperty();
    queryChartsAggList();
});


import { getWebSocket } from '@/utils/websocket';
import { map } from 'rxjs/operators';
const subRef = ref();
const dataSource = ref<PropertyData[]>([]);
const payloadData = ref<any>({name:'AAA'});
const subscribeProperty = () =>{
    const id = `instance-info-property-${deviceIns.value?.id}-${
        deviceIns.value?.productId
    }-${metadata?.value?.properties.map((i: Record<string, any>) => i.id).join('-')}`;
    const topic = `/dashboard/device/${deviceIns.value?.productId}/properties/realTime`;
    subRef.value = getWebSocket(id, topic, {
        deviceId: deviceIns.value?.id,
        properties: dataSource.value.map((i: Record<string, any>) => i.id),
        history: 1,
    })
        ?.pipe(map((res: any) => res.payload))
        .subscribe((payload) => {        
            payloadData.value = payload;
        });
};



//图表数据
import { getRangeTime } from '@/utils/utils';
import { getPropertiesInfo } from '@/api/device/instance';
const chartValue = ref<Record<string, any>>({});
const queryChartsAggList = async () => {
    const d = getRangeTime('week');
    const resp = await getPropertiesInfo(deviceIns.value?.id+'', {
        columns: [
            {
                property: "temperature",
                alias: "temperature",
                agg: 'MAX',
            },
            {
                property: "humidity",
                alias: "humidity",
                agg: 'MAX',
            }
        ],
        query: {
            interval: '1d',
            //format: 'yyyy-MM-dd HH:mm:ss',
            format: 'yyyy-MM-dd',
            from: d[0],
            to: d[1],
        }
    });
    if (resp.status === 200) {
        const series: any[] = [
            {  name:'温度',code:'temperature',data:[]},
            { name:'湿度',code:'humidity',data:[],
                type: 'line',
                smooth: 0.6,
                symbol: 'none',
                areaStyle: {
                    colorList:['rgba(84, 255, 159, 0.8)','rgba(217, 217, 217, 0)']
                },
                lineStyle: {
                    width: 2
                }    
            }
            ];
        const xAxis:any = {data:[]};
        (resp.result as any[]).forEach((i: any) => {
            series[0].data.unshift(Number(i["temperature"]));
            series[1].data.unshift(Number(i["humidity"]));
            xAxis.data.unshift(i.time);
        });  
        // dataList.sort((a,b)=>{
        //     return a[0]>b[0]?1:-1;
        // });     
        chartValue.value = {
            title: '近期环境曲线',
            series: series,
            xAxis: xAxis,
            legend:["温度","湿度"],
            data:null
        }
    }
};

</script>
<style scoped lang="less">
.page-top-left {
    flex: 5;
    margin-right: 16px;
}
.page-top-right {
    flex: 11;
    .page-top-right-top {
        display: flex;
    }
}
</style>
